@@ -496,7 +496,7 @@ static int open_pcm(oss_dsp_t *dsp, const char *name, unsigned int pcm_mode,
 	return result;
 }
 
-static int oss_dsp_open(int card, int device, int oflag, mode_t mode)
+static int oss_dsp_open(int card, int device, int oflag, mode_t mode ATTRIBUTE_UNUSED)
 {
 	oss_dsp_t *dsp;
 	unsigned int pcm_mode = 0;
@@ -534,7 +534,7 @@ static int oss_dsp_open(int card, int device, int oflag, mode_t mode)
 		errno = ENOENT;
 		return -1;
 	}
-	if (mode & O_NONBLOCK)
+	if (oflag & O_NONBLOCK)
 		pcm_mode = SND_PCM_NONBLOCK;
 	switch (oflag & O_ACCMODE) {
 	case O_RDONLY:
@@ -588,14 +588,16 @@ static int oss_dsp_open(int card, int device, int oflag, mode_t mode)
 		if (card == 0 && (device == OSS_DEVICE_DSP || device == OSS_DEVICE_AUDIO))
 			strcpy(name, "default");
 		else
-			sprintf(name, "plughw:%d", card);
+			sprintf(name, "default:%d", card);
 		result = open_pcm(dsp, name, pcm_mode, streams);
 		if (result < 0)
 			goto _error;
 	}
 	result = oss_dsp_params(dsp);
-	if (result < 0)
+	if (result < 0) {
+		DEBUG("Error setting params\n");
 		goto _error;
+	}
 	xfd->fileno = fd;
 	insert_fd(xfd);
 	return fd;
